#!/usr/bin/python3
# -*- coding: iso-8859-1 -*-
#
__author__="atareao"
__date__ ="$22-jan-2012$"
#
#
# Copyright (C) 2012 Lorenzo Carbonell
# lorenzo.carbonell.cerezo@gmail.com
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#
#
from gi.repository import Nautilus
from gi.repository import GObject
from gi.repository import Gtk
import tempfile
import shutil
import os
import sys
if sys.version_info[0] == 3:	
	from pypdf2 import PdfFileWriter, PdfFileReader
else:
	from pyPdf import PdfFileWriter, PdfFileReader

import locale
import gettext

LANGDIR = '/usr/share/locale-langpack'
APP = 'nautilus-pdftools'
VERSION = '0.6.3'

locale.setlocale(locale.LC_ALL, '')
gettext.bindtextdomain(APP, LANGDIR)
gettext.textdomain(APP)
_ = gettext.gettext	

########################################################################
class JoinPdfsDialog(Gtk.Dialog):
	def __init__(self,title,files):
		Gtk.Dialog.__init__(self,title,None,Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,(Gtk.STOCK_OK, Gtk.ResponseType.ACCEPT,Gtk.STOCK_CANCEL,Gtk.ResponseType.CANCEL))
		self.set_size_request(450, 300)
		self.set_resizable(False)
		#self.set_icon_from_file(comun.ICON)
		self.set_icon_name('application-pdf')
		self.connect('destroy', self.close_application)
		#
		vbox0 = Gtk.VBox(spacing = 5)
		vbox0.set_border_width(5)
		self.get_content_area().add(vbox0)
		#
		hbox = Gtk.HBox()
		vbox0.pack_start(hbox,True,True,0)
		#
		scrolledwindow = Gtk.ScrolledWindow()
		scrolledwindow.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
		scrolledwindow.set_shadow_type(Gtk.ShadowType.ETCHED_OUT)
		scrolledwindow.set_size_request(450,300)
		hbox.pack_start(scrolledwindow,True,True,0)
		#
		# id, text, image
		self.store = Gtk.ListStore(str)
		self.treeview = Gtk.TreeView(model=self.store)	
		self.treeview.append_column(Gtk.TreeViewColumn(_('Pdf file'), Gtk.CellRendererText(), text=0))		
		scrolledwindow.add(self.treeview)
		#
		vbox2 = Gtk.VBox(spacing = 0)
		vbox2.set_border_width(5)
		hbox.pack_start(vbox2,False,False,0)
		#
		self.button1 = Gtk.Button()
		self.button1.set_size_request(40,40)
		self.button1.set_tooltip_text(_('Up'))	
		self.button1.set_image(Gtk.Image.new_from_stock(Gtk.STOCK_GO_UP,Gtk.IconSize.BUTTON))
		self.button1.connect('clicked',self.on_button_up_clicked)
		vbox2.pack_start(self.button1,False,False,0)
		#
		self.button2 = Gtk.Button()
		self.button2.set_size_request(40,40)
		self.button2.set_tooltip_text(_('Down'))	
		self.button2.set_image(Gtk.Image.new_from_stock(Gtk.STOCK_GO_DOWN,Gtk.IconSize.BUTTON))
		self.button2.connect('clicked',self.on_button_down_clicked)
		vbox2.pack_start(self.button2,False,False,0)
		#
		self.button3 = Gtk.Button()
		self.button3.set_size_request(40,40)
		self.button3.set_tooltip_text(_('Add'))		
		self.button3.set_image(Gtk.Image.new_from_stock(Gtk.STOCK_ADD,Gtk.IconSize.BUTTON))
		self.button3.connect('clicked',self.on_button_add_clicked)
		vbox2.pack_start(self.button3,False,False,0)
		#
		self.button4 = Gtk.Button()
		self.button4.set_size_request(40,40)
		self.button4.set_tooltip_text(_('Remove'))		
		self.button4.set_image(Gtk.Image.new_from_stock(Gtk.STOCK_REMOVE,Gtk.IconSize.BUTTON))
		self.button4.connect('clicked',self.on_button_remove_clicked)
		vbox2.pack_start(self.button4,False,False,0)
		#
		for afile in files:
			self.store.append([afile])
		#
		self.show_all()	
		
	def on_button_up_clicked(self,widget):
		selection = self.treeview.get_selection()
		if selection.count_selected_rows()>0:
			model,iter = selection.get_selected()
			treepath = model.get_path(iter)
			path = int(str(treepath))
			if path > 0:
				previous_path = Gtk.TreePath.new_from_string(str(path - 1))
				previous_iter = model.get_iter(previous_path)
				model.swap(iter,previous_iter)
				
	def on_button_down_clicked(self,widget):
		selection = self.treeview.get_selection()
		if selection.count_selected_rows()>0:
			model,iter = selection.get_selected()
			treepath = model.get_path(iter)
			path = int(str(treepath))
			if path < len(model)-1:
				next_path = Gtk.TreePath.new_from_string(str(path + 1))
				next_iter = model.get_iter(next_path)
				model.swap(iter,next_iter)

	def on_button_add_clicked(self,widget):
		selection = self.treeview.get_selection()
		if selection.count_selected_rows()>0:
			model,iter = selection.get_selected()
			treepath = model.get_path(iter)
			position = int(str(treepath))
			dialog = Gtk.FileChooserDialog(_('Select one or more pdf files'),
											self,
										   Gtk.FileChooserAction.OPEN,
										   (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
											Gtk.STOCK_OPEN, Gtk.ResponseType.OK))
			dialog.set_default_response(Gtk.ResponseType.OK)
			dialog.set_select_multiple(True)
			dialog.set_current_folder(os.getenv('HOME'))
			filter = Gtk.FileFilter()
			filter.set_name(_('Pdf files'))
			filter.add_mime_type('application/pdf')
			filter.add_pattern('*.pdf')
			dialog.add_filter(filter)
			preview = Gtk.Image()
			response = dialog.run()
			if response == Gtk.ResponseType.OK:
				filenames = dialog.get_filenames()
				if len(filenames)>0:
					for i,filename in enumerate(filenames):
						model.insert(position+i+1,[filename])
			dialog.destroy()			


	def on_button_remove_clicked(self,widget):
		selection = self.treeview.get_selection()
		if selection.count_selected_rows()>0:
			model,iter = selection.get_selected()
			model.remove(iter)

	def close_application(self,widget):
		self.hide()

	def get_pdf_files(self):
		files = []
		iter = self.store.get_iter_first()
		while(iter):
			files.append(self.store.get_value(iter,0))
			iter = self.store.iter_next(iter)
		return files
			

class SelectPagesRotateDialog(Gtk.Dialog):
	def __init__(self, title, last_page):
		Gtk.Dialog.__init__(self,title,None,Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,(Gtk.STOCK_OK, Gtk.ResponseType.ACCEPT,Gtk.STOCK_CANCEL,Gtk.ResponseType.CANCEL))
		self.set_size_request(300, 140)
		self.set_resizable(False)
		#self.set_icon_from_file(comun.ICON)
		self.set_icon_name('application-pdf')
		self.connect('destroy', self.close_application)
		#
		vbox0 = Gtk.VBox(spacing = 5)
		vbox0.set_border_width(5)
		self.get_content_area().add(vbox0)
		#
		notebook = Gtk.Notebook()
		vbox0.add(notebook)
		#
		frame1 = Gtk.Frame()
		notebook.append_page(frame1,tab_label = Gtk.Label(_('Select Pages')))
		#
		table1 = Gtk.Table(rows = 3, columns = 3, homogeneous = False)
		table1.set_border_width(5)
		table1.set_col_spacings(5)
		table1.set_row_spacings(5)
		frame1.add(table1)
		#
		label1 = Gtk.Label(_('Pages')+':')
		label1.set_tooltip_text(_('Type page number and/or page\nranges separated by commas\ncounting from start of the\ndocument ej. 1,4,6-9'))
		label1.set_alignment(0,.5)
		table1.attach(label1,0,1,0,1, xoptions = Gtk.AttachOptions.FILL, yoptions = Gtk.AttachOptions.SHRINK)
		#
		self.entry1 = Gtk.Entry()
		self.entry1.set_tooltip_text(_('Type page number and/or page\nranges separated by commas\ncounting from start of the\ndocument ej. 1,4,6-9'))
		table1.attach(self.entry1,1,3,0,1, xoptions = Gtk.AttachOptions.EXPAND, yoptions = Gtk.AttachOptions.SHRINK)
		#
		self.rbutton1 = Gtk.RadioButton.new_from_widget(None)
		self.rbutton1.add(Gtk.Image.new_from_icon_name('object-rotate-left',Gtk.IconSize.BUTTON))
		table1.attach(self.rbutton1,0,1,2,3, xoptions = Gtk.AttachOptions.EXPAND, yoptions = Gtk.AttachOptions.SHRINK)
		self.rbutton2 = Gtk.RadioButton.new_from_widget(self.rbutton1)
		self.rbutton2.add(Gtk.Image.new_from_icon_name('object-rotate-right',Gtk.IconSize.BUTTON))
		table1.attach(self.rbutton2,1,2,2,3, xoptions = Gtk.AttachOptions.EXPAND, yoptions = Gtk.AttachOptions.SHRINK)
		self.rbutton3 = Gtk.RadioButton.new_from_widget(self.rbutton1)
		self.rbutton3.add(Gtk.Image.new_from_icon_name('object-flip-vertical',Gtk.IconSize.BUTTON))
		table1.attach(self.rbutton3,2,3,2,3, xoptions = Gtk.AttachOptions.EXPAND, yoptions = Gtk.AttachOptions.SHRINK)
		self.show_all()
	def close_application(self,widget):
		self.hide()
		
class SelectPagesDialog(Gtk.Dialog):
	def __init__(self, title, last_page):
		Gtk.Dialog.__init__(self,title,None,Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,(Gtk.STOCK_OK, Gtk.ResponseType.ACCEPT,Gtk.STOCK_CANCEL,Gtk.ResponseType.CANCEL))
		self.set_size_request(300, 120)
		self.set_resizable(False)
		#self.set_icon_from_file(comun.ICON)
		self.set_icon_name('application-pdf')
		self.connect('destroy', self.close_application)
		#
		vbox0 = Gtk.VBox(spacing = 5)
		vbox0.set_border_width(5)
		self.get_content_area().add(vbox0)
		#
		notebook = Gtk.Notebook()
		vbox0.add(notebook)
		#
		frame1 = Gtk.Frame()
		notebook.append_page(frame1,tab_label = Gtk.Label(_('Select Pages')))
		#
		table1 = Gtk.Table(rows = 3, columns = 3, homogeneous = False)
		table1.set_border_width(5)
		table1.set_col_spacings(5)
		table1.set_row_spacings(5)
		frame1.add(table1)
		#
		label1 = Gtk.Label(_('Pages')+':')
		label1.set_tooltip_text(_('Type page number and/or page\nranges separated by commas\ncounting from start of the\ndocument ej. 1,4,6-9'))
		label1.set_alignment(0,.5)
		table1.attach(label1,0,1,0,1, xoptions = Gtk.AttachOptions.FILL, yoptions = Gtk.AttachOptions.SHRINK)
		#
		self.entry1 = Gtk.Entry()
		self.entry1.set_tooltip_text(_('Type page number and/or page\nranges separated by commas\ncounting from start of the\ndocument ej. 1,4,6-9'))
		table1.attach(self.entry1,1,3,0,1, xoptions = Gtk.AttachOptions.EXPAND, yoptions = Gtk.AttachOptions.SHRINK)
		#
		self.show_all()
	def close_application(self,widget):
		self.hide()
	
class CombineDialog(Gtk.Dialog):
	def __init__(self, title):
		Gtk.Dialog.__init__(self,title,None,Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,(Gtk.STOCK_OK, Gtk.ResponseType.ACCEPT,Gtk.STOCK_CANCEL,Gtk.ResponseType.CANCEL))
		self.set_size_request(350, 150)
		self.set_resizable(False)
		#self.set_icon_from_file(comun.ICON)
		self.set_icon_name('application-pdf')
		self.connect('destroy', self.close_application)
		#
		vbox0 = Gtk.VBox(spacing = 5)
		vbox0.set_border_width(5)
		self.get_content_area().add(vbox0)
		#
		notebook = Gtk.Notebook()
		vbox0.add(notebook)
		#
		frame1 = Gtk.Frame()
		notebook.append_page(frame1,tab_label = Gtk.Label(_('Pages')))
		#
		table1 = Gtk.Table(rows = 5, columns = 4, homogeneous = False)
		table1.set_border_width(5)
		table1.set_col_spacings(5)
		table1.set_row_spacings(5)
		frame1.add(table1)
		#
		label1 = Gtk.Label(_('Paper size')+':')
		label1.set_tooltip_text(_('Select the size of the output file'))
		label1.set_alignment(0,.5)
		table1.attach(label1,0,1,0,1, xoptions = Gtk.AttachOptions.FILL, yoptions = Gtk.AttachOptions.SHRINK)
		#
		label2 = Gtk.Label(_('Orientation')+':')
		label2.set_tooltip_text(_('Select the orientation of the page'))
		label2.set_alignment(0,.5)
		table1.attach(label2,0,1,1,2, xoptions = Gtk.AttachOptions.FILL, yoptions = Gtk.AttachOptions.SHRINK)
		#
		label3 = Gtk.Label(_('Pages in Page')+':')
		label3.set_tooltip_text(_('Select how many pages in a page'))
		label3.set_alignment(0,.5)
		table1.attach(label3,0,1,2,3, xoptions = Gtk.AttachOptions.FILL, yoptions = Gtk.AttachOptions.SHRINK)
		#
		label4 = Gtk.Label(_('by'))
		label4.set_tooltip_text(_('rows by columns'))
		label4.set_alignment(.5,.5)
		table1.attach(label4,2,3,2,3, xoptions = Gtk.AttachOptions.FILL, yoptions = Gtk.AttachOptions.SHRINK)		
		#
		label5 = Gtk.Label(_('Sort')+':')
		label5.set_tooltip_text(_('Select the combination sort'))
		label5.set_alignment(0,.5)
		table1.attach(label5,0,1,3,4, xoptions = Gtk.AttachOptions.FILL, yoptions = Gtk.AttachOptions.SHRINK)
		#
		label6 = Gtk.Label(_('Set the margin')+':')
		label6.set_tooltip_text(_('The margin to the page in mm'))
		label6.set_alignment(0,.5)
		table1.attach(label6,0,1,4,5, xoptions = Gtk.AttachOptions.FILL, yoptions = Gtk.AttachOptions.SHRINK)
		#
		liststore = Gtk.ListStore(str, float, float)
		liststore.append(['A0', 3364.0, 4757.0])
		liststore.append(['A1', 2378.0, 3364.0])
		liststore.append(['A2', 1682.0, 2378.0])
		liststore.append(['A3', 1189.0, 1682.0])
		liststore.append(['A4', 841.0, 1189.0])
		liststore.append(['A5', 594.0, 841.0])
		liststore.append(['A6', 420.0, 594.0])
		liststore.append(['A7', 297.0, 420.0])
		liststore.append(['A8', 210.0, 297.0])
		liststore.append(['A9', 148.0, 210.0])
		liststore.append(['A10', 105.0, 148.0])
		liststore.append(['A7', 74.0, 105.0])
		liststore.append(['A8', 52.0, 74.0])
		liststore.append(['A9', 37.0, 52.0])
		liststore.append(['A10', 26.0, 37.0])
		liststore.append(['Carta (11x8 1/2)', 279.0, 216.0])
		liststore.append(['Folio (13x8 1/2)', 330.0, 216.0])
		liststore.append(['Legal (14x8 1/2)', 356.0, 216.0])
		liststore.append(['Tabloid (17x11)', 432.0, 279.0])		
		self.entry1 = Gtk.ComboBox.new_with_model(model=liststore)
		renderer_text = Gtk.CellRendererText()
		self.entry1.pack_start(renderer_text, True)
		self.entry1.add_attribute(renderer_text, "text", 0)
		self.entry1.set_active(0)
		table1.attach(self.entry1,1,4,0,1, xoptions = Gtk.AttachOptions.FILL, yoptions = Gtk.AttachOptions.SHRINK)
		#
		liststore = Gtk.ListStore(str)
		liststore.append([_('Vertical')])
		liststore.append([_('Horizontal')])
		self.entry2 = Gtk.ComboBox.new_with_model(model=liststore)
		renderer_text = Gtk.CellRendererText()
		self.entry2.pack_start(renderer_text, True)
		self.entry2.add_attribute(renderer_text, "text", 0)
		self.entry2.set_active(0)
		table1.attach(self.entry2,1,4,1,2, xoptions = Gtk.AttachOptions.FILL, yoptions = Gtk.AttachOptions.SHRINK)
		#
		self.entry3 = Gtk.SpinButton()
		self.entry3.set_adjustment(Gtk.Adjustment(1,1,100,1,10,10))
		table1.attach(self.entry3,1,2,2,3, xoptions = Gtk.AttachOptions.FILL, yoptions = Gtk.AttachOptions.SHRINK)
		#
		self.entry4 = Gtk.SpinButton()
		self.entry4.set_adjustment(Gtk.Adjustment(1,1,100,1,10,10))
		table1.attach(self.entry4,3,4,2,3, xoptions = Gtk.AttachOptions.FILL, yoptions = Gtk.AttachOptions.SHRINK)
		#
		liststore = Gtk.ListStore(str)
		liststore.append([_('By rows')])
		liststore.append([_('By columns')])
		self.entry5 = Gtk.ComboBox.new_with_model(model=liststore)
		renderer_text = Gtk.CellRendererText()
		self.entry5.pack_start(renderer_text, True)
		self.entry5.add_attribute(renderer_text, "text", 0)
		self.entry5.set_active(0)
		table1.attach(self.entry5,1,4,3,4, xoptions = Gtk.AttachOptions.FILL, yoptions = Gtk.AttachOptions.SHRINK)
		#
		self.entry6 = Gtk.SpinButton()
		self.entry6.set_adjustment(Gtk.Adjustment(0,0,100,1,10,10))
		table1.attach(self.entry6,1,4,4,5, xoptions = Gtk.AttachOptions.FILL, yoptions = Gtk.AttachOptions.SHRINK)
		#
		self.show_all()

	def get_size(self):
		tree_iter = self.entry1.get_active_iter()
		if tree_iter != None:
			model = self.entry1.get_model()
			w = model[tree_iter][1]
			h = model[tree_iter][2]
			return w,h
		return None

	def is_vertical(self):
		tree_iter = self.entry2.get_active_iter()
		if tree_iter != None:
			model = self.entry2.get_model()
			vertical = model[tree_iter][0]
			if vertical == _('Vertical'):
				return True
		return False

	def get_rows(self):
		return self.entry3.get_value()

	def get_columns(self):
		return self.entry4.get_value()
	
	def is_sort_by_rows(self):
		tree_iter = self.entry5.get_active_iter()
		if tree_iter != None:
			model = self.entry5.get_model()
			vertical = model[tree_iter][0]
			if vertical ==_('By rows'):
				return True
		return False
	def get_margin(self):
		return self.entry6.get_value()
		
	def close_application(self,widget):
		self.hide()	
		
class ResizeDialog(Gtk.Dialog):
	def __init__(self, title):
		Gtk.Dialog.__init__(self,title,None,Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,(Gtk.STOCK_OK, Gtk.ResponseType.ACCEPT,Gtk.STOCK_CANCEL,Gtk.ResponseType.CANCEL))
		self.set_size_request(350, 150)
		self.set_resizable(False)
		#self.set_icon_from_file(comun.ICON)
		self.set_icon_name('application-pdf')
		self.connect('destroy', self.close_application)
		#
		vbox0 = Gtk.VBox(spacing = 5)
		vbox0.set_border_width(5)
		self.get_content_area().add(vbox0)
		#
		notebook = Gtk.Notebook()
		vbox0.add(notebook)
		#
		frame1 = Gtk.Frame()
		notebook.append_page(frame1,tab_label = Gtk.Label(_('Pages')))
		#
		table1 = Gtk.Table(rows = 5, columns = 4, homogeneous = False)
		table1.set_border_width(5)
		table1.set_col_spacings(5)
		table1.set_row_spacings(5)
		frame1.add(table1)
		#
		label1 = Gtk.Label(_('Paper size')+':')
		label1.set_tooltip_text(_('Select the size of the output file'))
		label1.set_alignment(0,.5)
		table1.attach(label1,0,1,0,1, xoptions = Gtk.AttachOptions.FILL, yoptions = Gtk.AttachOptions.SHRINK)
		#
		label2 = Gtk.Label(_('Orientation')+':')
		label2.set_tooltip_text(_('Select the orientation of the page'))
		label2.set_alignment(0,.5)
		table1.attach(label2,0,1,1,2, xoptions = Gtk.AttachOptions.FILL, yoptions = Gtk.AttachOptions.SHRINK)
		#
		liststore = Gtk.ListStore(str, float, float)
		liststore.append(['A0', 3364.0, 4757.0])
		liststore.append(['A1', 2378.0, 3364.0])
		liststore.append(['A2', 1682.0, 2378.0])
		liststore.append(['A3', 1189.0, 1682.0])
		liststore.append(['A4', 841.0, 1189.0])
		liststore.append(['A5', 594.0, 841.0])
		liststore.append(['A6', 420.0, 594.0])
		liststore.append(['A7', 297.0, 420.0])
		liststore.append(['A8', 210.0, 297.0])
		liststore.append(['A9', 148.0, 210.0])
		liststore.append(['A10', 105.0, 148.0])
		liststore.append(['A7', 74.0, 105.0])
		liststore.append(['A8', 52.0, 74.0])
		liststore.append(['A9', 37.0, 52.0])
		liststore.append(['A10', 26.0, 37.0])
		liststore.append(['Carta (11x8 1/2)', 279.0, 216.0])
		liststore.append(['Folio (13x8 1/2)', 330.0, 216.0])
		liststore.append(['Legal (14x8 1/2)', 356.0, 216.0])
		liststore.append(['Tabloid (17x11)', 432.0, 279.0])
		self.entry1 = Gtk.ComboBox.new_with_model(model=liststore)
		renderer_text = Gtk.CellRendererText()
		self.entry1.pack_start(renderer_text, True)
		self.entry1.add_attribute(renderer_text, "text", 0)
		self.entry1.set_active(0)
		table1.attach(self.entry1,1,4,0,1, xoptions = Gtk.AttachOptions.FILL, yoptions = Gtk.AttachOptions.SHRINK)
		#
		liststore = Gtk.ListStore(str)
		liststore.append([_('Vertical')])
		liststore.append([_('Horizontal')])
		self.entry2 = Gtk.ComboBox.new_with_model(model=liststore)
		renderer_text = Gtk.CellRendererText()
		self.entry2.pack_start(renderer_text, True)
		self.entry2.add_attribute(renderer_text, "text", 0)
		self.entry2.set_active(0)
		table1.attach(self.entry2,1,4,1,2, xoptions = Gtk.AttachOptions.FILL, yoptions = Gtk.AttachOptions.SHRINK)
		#
		self.show_all()

	def get_size(self):
		tree_iter = self.entry1.get_active_iter()
		if tree_iter != None:
			model = self.entry1.get_model()
			w = model[tree_iter][1]
			h = model[tree_iter][2]
			return w,h
		return None

	def is_vertical(self):
		tree_iter = self.entry2.get_active_iter()
		if tree_iter != None:
			model = self.entry2.get_model()
			vertical = model[tree_iter][0]
			if vertical == _('Vertical'):
				return True
		return False
	
	def close_application(self,widget):
		self.hide()		
########################################################################

def create_temp_file():
	return tempfile.mkstemp(prefix = 'tmp_nautilus_pdftools_')[1]

def dialog_save_as(title, original_file):
	# dialog.run()
	# if response == Gtk.ResponseType.OK:
	dialog = Gtk.FileChooserDialog(title,
									None,
								   Gtk.FileChooserAction.SAVE,
								   (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
									Gtk.STOCK_OPEN, Gtk.ResponseType.OK))
	dialog.set_default_response(Gtk.ResponseType.OK)
	dialog.set_current_folder(os.path.dirname(original_file))
	dialog.set_filename(original_file)
	filter = Gtk.FileFilter()
	filter.set_name(_('Pdf files'))
	filter.add_mime_type('application/pdf')
	filter.add_pattern('*.pdf')
	dialog.add_filter(filter)
	if dialog.run() == Gtk.ResponseType.OK:
		filename = dialog.get_filename()
		if not filename.endswith('.pdf'):
			filename += '.pdf'
	else:
		filename = None
	dialog.destroy()
	return filename

def dialog_save_as_text(title, original_file):
	dialog = Gtk.FileChooserDialog(title,
									None,
								   Gtk.FileChooserAction.SAVE,
								   (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
									Gtk.STOCK_OPEN, Gtk.ResponseType.OK))
	dialog.set_default_response(Gtk.ResponseType.OK)
	dialog.set_current_folder(os.path.dirname(original_file))
	dialog.set_filename(original_file)
	filter = Gtk.FileFilter()
	filter.set_name(_('Text file'))
	filter.add_mime_type('text/plain')
	filter.add_pattern('*.txt')
	dialog.add_filter(filter)
	if dialog.run() == Gtk.ResponseType.OK:
		filename = dialog.get_filename()
		if not filename.endswith('.txt'):
			filename += '.txt'
	else:
		filename = None
	dialog.destroy()
	return filename

		
########################################################################

def rotate_pdf(file_in,file_out,degrees):
	print(file_in)
	output = PdfFileWriter()
	print(output)
	input1 = PdfFileReader(open(file_in,'rb'))
	print(input1)
	for i in range(0,input1.getNumPages()):
		output.addPage(input1.getPage(i).rotateClockwise(degrees))
	outputStream = open(file_out, 'wb')
	output.write(outputStream)
	outputStream.close()

def split_pdf(file_in):
	input1 = PdfFileReader(file(file_in,'rb'))
	if input1.getNumPages() > 1:
		file_out,ext = os.path.splitext(file_in)
		for i in range(0,input1.getNumPages()):
			file_out_i = '%s_%s%s'%(file_out,i+1,ext)
			output = PdfFileWriter()
			output.addPage(input1.getPage(i))
			outputStream = file(file_out_i, 'wb')
			output.write(outputStream)
			outputStream.close()

def resize(file_in,file_out,width=1189,height=1682):
	output = PdfFileWriter()
	input1 = PdfFileReader(file(file_in, "rb"))
	width = float(width)
	height = float(height)
	horizontal = (width > height)
	print(horizontal)
	for i in range(0,input1.getNumPages()):		
		page0 = output.addBlankPage(width,height)
		pagei = input1.getPage(i)
		widthi = float((pagei.mediaBox.getUpperRight_x() - pagei.mediaBox.getLowerLeft_x ()))
		heighti = float(pagei.mediaBox.getUpperRight_y() - pagei.mediaBox.getLowerLeft_x ())
		print((widthi,heighti))
		horizontali = (widthi > heighti)
		if horizontal != horizontali:
			sw = width/heighti
			sh = height/widthi
			if sw<sh:
				scale = sw
			else:
				scale = sh
			print(scale)	
			page0.mergeRotatedScaledTranslatedPage(pagei,-90,scale,0,scale*widthi)
		else:
			sw = width/widthi
			sh = height/heighti
			if sw<sh:
				scale = sw
			else:
				scale = sh
			print(scale)
			pagei.scaleBy(scale)			
			page0.mergePage(pagei)
	page0.compressContentStreams()
	outputStream = open(file_out, "wb")
	output.write(outputStream)
	outputStream.close()

def combine(file_in,file_out,filas=1,columnas=2,width=297,height=210,margen=0.0,byrows=True ):
	output = PdfFileWriter()
	input1 = PdfFileReader(open(file_in, "rb"))
	filas = float(filas)
	columnas = float(columnas)
	width = float(width)
	height = float(height)
	margen = float(margen)
	for i in range(0,input1.getNumPages(),int(filas*columnas)):		
		page0 = output.addBlankPage(width,height)
		page = i-1	
		for fila in range(0,int(filas)):
			for columna in range(0,int(columnas)):			
				page += 1
				if byrows:
					aux_combine(page,input1,fila,columna,width,height,filas,columnas,margen,page0)
				else:
					aux_combine(page,input1,columna,fila,width,height,filas,columnas,margen,page0)
	outputStream = open(file_out, "wb")
	output.write(outputStream)
	outputStream.close()

def aux_combine(page,input1,fila,columna,width,height,filas,columnas,margen,page0):
	if page < input1.getNumPages():	
		pagei = input1.getPage(page)
		widthi = float(pagei.mediaBox.getWidth())
		heighti = float(pagei.mediaBox.getHeight())
		sw = (width-(filas+1.0)*margen)/widthi/columnas
		sh = (height-(columnas+1.0)*margen)/heighti/filas
		if sw<sh:
			scale = sw
		else:
			scale = sh
		print(scale)
		pagei.scaleBy(scale)
		x = float(columna) * width /columnas + (float(columna)+1.0)*margen
		y = (filas - float(fila) - 1.0) * height /float(filas) + (float(fila)+1.0)*margen
		page0.mergeTranslatedPage(pagei, x, y)
		page0.compressContentStreams()
	else:
		return
			
def remove_ranges(file_in,file_out,ranges):
	pages =[]
	for rang in ranges:
		if len(rang)>1:
			for i in range(rang[0],rang[1]+1):
				if not i in pages:
					pages.append(i)
		else:
			if not rang[0] in pages:
				pages.append(rang[0])	
	output = PdfFileWriter()
	input1 = PdfFileReader(open(file_in,'rb'))
	for i in range(0,input1.getNumPages()):
		if i+1 not in pages:
			output.addPage(input1.getPage(i))
	temp = create_temp_file()
	outputStream = open(temp, 'wb')
	output.write(outputStream)
	outputStream.close()
	shutil.copyfile(temp, file_out)
	os.remove(temp)
	
def rotate_ranges_in_pdf(file_in,file_out,degrees,ranges):
	pages =[]
	for rang in ranges:
		if len(rang)>1:
			for i in range(rang[0],rang[1]+1):
				if not i in pages:
					pages.append(i)
		else:
			if not rang[0] in pages:
				pages.append(rang[0])
	output = PdfFileWriter()
	input1 = PdfFileReader(open(file_in,'rb'))
	for i in range(0,input1.getNumPages()):
		if i+1 in pages:
			output.addPage(input1.getPage(i).rotateClockwise(degrees))
		else:
			output.addPage(input1.getPage(i))
	temp = create_temp_file()
	outputStream = open(temp, 'wb')
	output.write(outputStream)
	outputStream.close()
	shutil.copyfile(temp, file_out)
	os.remove(temp)

def extract_text(file_in, file_out):
	text = ''
	input1 = PdfFileReader(open(file_in,'rb'))
	for i in range(0,input1.getNumPages()):
		text += input1.getPage(i).extractText()
	fw = open(file_out,'w')
	fw.write(text)
	fw.close()

def convert2png(file_in,file_out):
	im=Image.open(file_in)
	im.save(file_out)

def extract_ranges(file_in,file_out,ranges):
	pages =[]
	for rang in ranges:
		if len(rang)>1:
			for i in range(rang[0],rang[1]+1):
				if not i in pages:
					pages.append(i)
		else:
			if not rang[0] in pages:
				pages.append(rang[0])	
	output = PdfFileWriter()
	input1 = PdfFileReader(open(file_in,'rb'))
	for i in range(0,input1.getNumPages()):
		if i+1 in pages:
			output.addPage(input1.getPage(i))
	temp = create_temp_file()
	outputStream = open(temp, 'wb')
	output.write(outputStream)
	outputStream.close()
	shutil.copyfile(temp, file_out)
	os.remove(temp)

def rotate_some_pages_in_pdf(file_in,file_out,degrees,first_page,last_page):
	output = PdfFileWriter()
	input1 = PdfFileReader(open(file_in,'rb'))
	for i in range(0,input1.getNumPages()):
		if i>=first_page and i<=last_page:
			output.addPage(input1.getPage(i).rotateClockwise(degrees))
		else:
			output.addPage(input1.getPage(i))
	temp = create_temp_file()
	outputStream = open(temp, 'wb')
	output.write(outputStream)
	outputStream.close()
	shutil.copyfile(temp, file_out)
	os.remove(temp)

def extract_pages(file_in,file_out,first_page,last_page):
	output = PdfFileWriter()
	input1 = PdfFileReader(open(file_in,'rb'))
	if first_page > input1.getNumPages()-1:
		first_page = input1.getNumPages()-1
	if last_page < first_page:
		last_page = first_page
	if last_page > input1.getNumPages()-1:
		last_page = input1.getNumPages()-1
	for i in range(first_page,last_page+1):
		output.addPage(input1.getPage(i))
	temp = create_temp_file()
	outputStream = open(temp, 'wb')
	output.write(outputStream)
	outputStream.close()
	shutil.copyfile(temp, file_out)
	os.remove(temp)

def remove_pages(file_in,file_out,first_page,last_page):
	output = PdfFileWriter()
	input1 = PdfFileReader(open(file_in,'rb'))
	if first_page > input1.getNumPages()-1:
		first_page = input1.getNumPages()-1
	if last_page < first_page:
		last_page = first_page
	if last_page > input1.getNumPages()-1:
		last_page = input1.getNumPages()-1
	for i in range(0,input1.getNumPages()):
		if i not in list(range(first_page,last_page+1)):
			output.addPage(input1.getPage(i))
	temp = create_temp_file()
	outputStream = open(temp, 'wb')
	output.write(outputStream)
	outputStream.close()
	shutil.copyfile(temp, file_out)
	os.remove(temp)

def join_files(files,file_out):
	output = PdfFileWriter()
	for file_in in files:
		input1 = PdfFileReader(open(file_in,'rb'))
		for i in range(0,input1.getNumPages()):
			output.addPage(input1.getPage(i))
	temp = create_temp_file()
	outputStream = open(temp, 'wb')
	output.write(outputStream)
	outputStream.close()
	shutil.copyfile(temp, file_out)
	os.remove(temp)
		
def encrypt_file(file_in, file_out, user_pwd, owner_pwd=None, use_128bit=True):
	output = PdfFileWriter()
	input1 = PdfFileReader(open(file_in,'rb'))
	for i in range(0,input1.getNumPages()):
		output.addPage(input1.getPage(i))
	output.encrypt(user_pwd, owner_pwd, use_128bit)
	outputStream = open(file_out, 'wb')
	output.write(outputStream)
	outputStream.close()

def decrypt_file(file_in, file_out, pwd):
	output = PdfFileWriter()
	input1 = PdfFileReader(open(file_in,'rb'))
	input1.decrypt(pwd)
	for i in range(0,input1.getNumPages()):
		output.addPage(input1.getPage(i))
	outputStream = open(file_out, 'wb')
	output.write(outputStream)
	outputStream.close()
	
	
def rotate_pdf_090(file_in,file_out):
	rotate_pdf(file_in,file_out,90)

def rotate_pdf_180(file_in,file_out):
	rotate_pdf(file_in,file_out,180)

def rotate_pdf_270(file_in,file_out):
	rotate_pdf(file_in,file_out,270)
	
def get_output_filename(file_in,modificator):
	if os.path.exists(file_in) and os.path.isfile(file_in):
		head, tail = os.path.split(file_in)
		root, ext = os.path.splitext(tail)
		file_out = os.path.join(head,root+'_'+modificator+ext)
		return file_out
	return None

def get_files(files_in):
	files = []
	for file_in in files_in:
		print(file_in)
		file_in = file_in.get_uri()[7:]
		if os.path.isfile(file_in):
			files.append(file_in)
	if len(files)>0:
		return files
	return None

def get_num(chain):
	try:
		chain = chain.strip() # removing spaces
		return int(float(chain))
	except:
		return None

def get_ranges(chain):
	ranges = []
	if chain.find(',') > -1:
		for part in chain.split(','):
			if part.find('-') > -1:
				parts = part.split('-')
				if len(parts) > 1:
					f = get_num(parts[0])
					t = get_num(parts[1])
					if f != None and t !=None:
						ranges.append([f,t])
			else:
				el = get_num(part)
				if el:
					ranges.append([el])
	elif chain.find('-') > -1:
		parts = chain.split('-')
		if len(parts) > 1:
			f = get_num(parts[0])
			t = get_num(parts[1])
			if f != None and t !=None:
				ranges.append([f,t])
	else:
		el = get_num(chain)
		if el:
			ranges.append([el])
	return ranges
		
########################################################################

"""
Tools to manipulate pdf
"""	
class PdfToolsMenuProvider(GObject.GObject, Nautilus.MenuProvider):
	"""Implements the 'Replace in Filenames' extension to the nautilus right-click menu"""

	def __init__(self):
		"""Nautilus crashes if a plugin doesn't implement the __init__ method"""
		pass

	def all_files_are_pdf(self,items):
		for item in items:
			fileName, fileExtension = os.path.splitext(item.get_uri()[7:])
			if fileExtension != '.pdf':
				return False
		return True

	def resize_pdf_pages(self,menu,selected):
		files = get_files(selected)
		if files:
			file_in = files[0]
			cd = ResizeDialog(_('Resize pages'))
			if cd.run() == Gtk.ResponseType.ACCEPT:
				size = cd.get_size()
				if cd.is_vertical():
					width = size[0]
					height = size[1]
				else:
					width = size[1]
					height = size[0]
				cd.destroy()
				file_out = dialog_save_as(_('Select file to save new file'), file_in)
				if file_out:
					resize(file_in,file_out,width,height)
			cd.destroy()

	def combine_pdf_pages(self,menu,selected):
		files = get_files(selected)
		if files:
			file_in = files[0]
			cd = CombineDialog(_('Combine pages'))
			if cd.run() == Gtk.ResponseType.ACCEPT:
				size = cd.get_size()
				if cd.is_vertical():
					width = size[0]
					height = size[1]
				else:
					width = size[1]
					height = size[0]
				filas = cd.get_rows()
				columnas = cd.get_columns()
				byrows = cd.is_sort_by_rows()
				margen = cd.get_margin()
				cd.destroy()
				file_out = dialog_save_as(_('Select file to save new file'), file_in)
				if file_out:
					combine(file_in,file_out,filas,columnas,width,height,margen,byrows )
			cd.destroy()
			
	def join_pdf_files(self,menu,selected):
		files = get_files(selected)
		if files:
			jpd = JoinPdfsDialog(_('Join pdf files'),files)
			if jpd.run() == Gtk.ResponseType.ACCEPT:
				files = jpd.get_pdf_files()
				jpd.destroy()
				if len(files)>0:
					file0 = os.path.join(os.path.dirname(files[0]),'joined_files.pdf')
					file_out = dialog_save_as(_('Select file to save new file'), file0)
					if file_out:
						join_files(files,file_out)
			jpd.destroy()

	def rotate_090_clockwise(self,menu,selected):
		files = get_files(selected)
		if files:
			for file_in in files:
				file_out = get_output_filename(file_in,'rotated_090')
				if file_out:
					rotate_pdf_090(file_in,file_out)

	def rotate_180_clockwise(self,menu,selected):
		files = get_files(selected)
		if files:
			for file_in in files:
				file_out = get_output_filename(file_in,'rotated_180')
				if file_out:
					rotate_pdf_180(file_in,file_out)

	def rotate_270_clockwise(self,menu,selected):
		files = get_files(selected)
		if files:
			for file_in in files:
				file_out = get_output_filename(file_in,'rotated_270')
				if file_out:
					rotate_pdf_270(file_in,file_out)

	def rotate_some_pages(self,menu,selected):
		files = get_files(selected)
		if files:
			file0 = files[0]
			reader = PdfFileReader(file(file0,'rb'))
			last_page = reader.getNumPages() 
			spd = SelectPagesRotateDialog(_('Rotate some pages'),last_page)
			if spd.run() == Gtk.ResponseType.ACCEPT:			
				ranges = get_ranges(spd.entry1.get_text())				
				if spd.rbutton1.get_active():
					degrees = 270
				elif spd.rbutton2.get_active():
					degrees = 90
				else:
					degrees = 180
				spd.destroy()
				if len(ranges)>0:
					file_out = dialog_save_as(_('Select file to save new file'), file0)
					if file_out:
						rotate_ranges_in_pdf(file0,file_out,degrees,ranges)
			else:
				spd.destroy()
				
	def about(self,menu,selected):
		ad=Gtk.AboutDialog()
		ad.set_name('Nautilus PdfTools')
		ad.set_icon_name('application-pdf')
		ad.set_version(VERSION)
		ad.set_copyright('Copyrignt (c) 2012\nLorenzo Carbonell')
		ad.set_comments(_('Tools to manage pdf files'))
		ad.set_license(''+
		'This program is free software: you can redistribute it and/or modify it\n'+
		'under the terms of the GNU General Public License as published by the\n'+
		'Free Software Foundation, either version 3 of the License, or (at your option)\n'+
		'any later version.\n\n'+
		'This program is distributed in the hope that it will be useful, but\n'+
		'WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY\n'+
		'or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for\n'+
		'more details.\n\n'+
		'You should have received a copy of the GNU General Public License along with\n'+
		'this program.  If not, see <http://www.gnu.org/licenses/>.')
		ad.set_website('http://www.atareao.es')
		ad.set_website_label('http://www.atareao.es')
		ad.set_authors(['Lorenzo Carbonell <lorenzo.carbonell.cerezo@gmail.com>'])
		ad.set_documenters(['Lorenzo Carbonell <lorenzo.carbonell.cerezo@gmail.com>'])
		ad.set_program_name('Nautilus PdfTools')
		ad.set_logo_icon_name('application-pdf')
		ad.run()
		ad.destroy()		
		
	def remove_some_pages(self,menu,selected):
		files = get_files(selected)
		if files:
			file0 = files[0]
			reader = PdfFileReader(file(file0,'rb'))
			last_page = reader.getNumPages() 
			spd = SelectPagesDialog(_('Remove some pages'),last_page)
			if spd.run() == Gtk.ResponseType.ACCEPT:
				ranges = get_ranges(spd.entry1.get_text())
				spd.destroy()
				if len(ranges)>0:
					file_out = dialog_save_as(_('Select file to save new file'), file0)
					if file_out:
						remove_ranges(file0,file_out,ranges)
			else:
				spd.destroy()

	def split_pdf_files(self,menu,selected):
		files = get_files(selected)
		if files:
			file0 = files[0]
			split_pdf(file0)
		
	def extract_some_pages(self,menu,selected):
		files = get_files(selected)
		if files:
			file0 = files[0]
			reader = PdfFileReader(file(file0,'rb'))
			last_page = reader.getNumPages() 
			spd = SelectPagesDialog(_('Extract some pages'),last_page)
			if spd.run() == Gtk.ResponseType.ACCEPT:
				ranges = get_ranges(spd.entry1.get_text())
				spd.destroy()
				if len(ranges)>0:				
					file_out = dialog_save_as(_('Select file to save extracted pages'), file0)
					if file_out:
						extract_ranges(file0,file_out,ranges)
			else:
				spd.destroy()
				
	def extract_text(self,menu,selected):
		files = get_files(selected)
		if files:
			file0 = files[0]
			file_out = dialog_save_as_text(_('Select file to save extracted text'), file0)
			if file_out:
				extract_text(file0,file_out)
		
	def get_file_items(self, window, sel_items):
		"""Adds the 'Replace in Filenames' menu item to the Nautilus right-click menu,
		   connects its 'activate' signal to the 'run' method passing the selected Directory/File"""
		if not self.all_files_are_pdf(sel_items):
			return
		top_menuitem = Nautilus.MenuItem(name='PdfToolsMenuProvider::Gtk-pdf-tools',
								 label=_('Pdf Tools'),
								 tip=_('Tools to manipulate pdf files'),
								 icon='Gtk-find-and-replace')
		#
		submenu = Nautilus.Menu()
		top_menuitem.set_submenu(submenu)
		#
		sub_menuitem_1 = Nautilus.MenuItem(name='PdfToolsMenuProvider::Gtk-pdf-tools-01',
								 label=_('Rotate to the right'),
								 tip=_('Rotate pdf files 90 degrees clockwise'),
								 icon='Gtk-find-and-replace')
		sub_menuitem_1.connect('activate', self.rotate_090_clockwise, sel_items)
		submenu.append_item(sub_menuitem_1)
		#
		sub_menuitem_2 = Nautilus.MenuItem(name='PdfToolsMenuProvider::Gtk-pdf-tools-03',
								 label=_('Rotate to the left'),
								 tip=_('Rotate 90 degrees couterclockwise'),
								 icon='Gtk-find-and-replace')
		sub_menuitem_2.connect('activate', self.rotate_270_clockwise, sel_items)
		submenu.append_item(sub_menuitem_2)
		#
		sub_menuitem_3 = Nautilus.MenuItem(name='PdfToolsMenuProvider::Gtk-pdf-tools-02',
								 label=_('Rotate 180 degrees'),
								 tip=_('Rotate 180 degrees clockwise'),
								 icon='Gtk-find-and-replace')
		sub_menuitem_3.connect('activate', self.rotate_180_clockwise, sel_items)
		submenu.append_item(sub_menuitem_3)
		#
		sub_menuitem_4 = Nautilus.MenuItem(name='PdfToolsMenuProvider::Gtk-pdf-tools-04',
								 label=_('Rotate pages'),
								 tip=_('Rotate pages of the document'),
								 icon='Gtk-find-and-replace')
		sub_menuitem_4.connect('activate', self.rotate_some_pages, sel_items)
		submenu.append_item(sub_menuitem_4)
		#
		sub_menuitem_5 = Nautilus.MenuItem(name='PdfToolsMenuProvider::Gtk-pdf-tools-05',
								 label=_('Remove pages'),
								 tip=_('Remove pages from the document'),
								 icon='Gtk-find-and-replace')
		sub_menuitem_5.connect('activate', self.remove_some_pages, sel_items)
		submenu.append_item(sub_menuitem_5)
		#
		sub_menuitem_6 = Nautilus.MenuItem(name='PdfToolsMenuProvider::Gtk-pdf-tools-06',
								 label=_('Extract pages'),
								 tip=_('Extract pages from the document'),
								 icon='Gtk-find-and-replace')
		sub_menuitem_6.connect('activate', self.extract_some_pages, sel_items)
		submenu.append_item(sub_menuitem_6)
		#		
		sub_menuitem_7 = Nautilus.MenuItem(name='PdfToolsMenuProvider::Gtk-pdf-tools-07',
								 label=_('Join pdf files'),
								 tip=_('Join pdf files in one document'),
								 icon='Gtk-find-and-replace')
		sub_menuitem_7.connect('activate', self.join_pdf_files, sel_items)
		submenu.append_item(sub_menuitem_7)
		#		
		sub_menuitem_8 = Nautilus.MenuItem(name='PdfToolsMenuProvider::Gtk-pdf-tools-08',
								 label=_('Split pdf file'),
								 tip=_('Split one pdf file'),
								 icon='Gtk-find-and-replace')
		sub_menuitem_8.connect('activate', self.split_pdf_files, sel_items)
		submenu.append_item(sub_menuitem_8)
		#		
		sub_menuitem_9 = Nautilus.MenuItem(name='PdfToolsMenuProvider::Gtk-pdf-tools-09',
								 label=_('Combine pdf pages'),
								 tip=_('Combine pdf pages in one page'),
								 icon='Gtk-find-and-replace')
		sub_menuitem_9.connect('activate', self.combine_pdf_pages, sel_items)
		submenu.append_item(sub_menuitem_9)
		#		
		sub_menuitem_10 = Nautilus.MenuItem(name='PdfToolsMenuProvider::Gtk-pdf-tools-10',
								 label=_('Resize pdf pages'),
								 tip=_('Resize pdf pages'),
								 icon='Gtk-find-and-replace')
		sub_menuitem_10.connect('activate', self.resize_pdf_pages, sel_items)
		submenu.append_item(sub_menuitem_10)
		#		
		sub_menuitem_11 = Nautilus.MenuItem(name='PdfToolsMenuProvider::Gtk-pdf-tools-11',
								 label=_('Extract text'),
								 tip=_('Extract text from pdf'),
								 icon='Gtk-find-and-replace')
		sub_menuitem_11.connect('activate', self.extract_text, sel_items)
		submenu.append_item(sub_menuitem_11)
		#		
		sub_menuitem_99 = Nautilus.MenuItem(name='PdfToolsMenuProvider::Gtk-pdf-tools-99',
								 label=_('About'),
								 tip=_('About'),
								 icon='Gtk-find-and-replace')
		sub_menuitem_99.connect('activate', self.about, sel_items)
		submenu.append_item(sub_menuitem_99)
		#		
		return top_menuitem,

if __name__ == '__main__':
	print('test')
	rotate_pdf_180('/home/atareao/Escritorio/ejemplo.pdf','/home/atareao/Escritorio/salida-out.pdf')
	extract_pages('/home/atareao/Escritorio/ejemplo.pdf','/home/atareao/Escritorio/salida-out.pdf',1,2)
	'''
	extract_pages('/home/atareao/Escritorio/sample.pdf','/home/atareao/Escritorio/sample-mod.pdf',1,2)
	files = ['/home/atareao/Escritorio/sample.pdf','/home/atareao/Escritorio/sample1.pdf','/home/atareao/Escritorio/sample2.pdf','/home/atareao/Escritorio/sample3.pdf']
	merge_files(files,'/home/atareao/Escritorio/sample-mod.pdf')
	encrypt_file('/home/atareao/Escritorio/sample.pdf','/home/atareao/Escritorio/sample_encripted.pdf','alfa','alfa',True)
	decrypt_file('/home/atareao/Escritorio/sample_encripted.pdf','/home/atareao/Escritorio/sample_decripted.pdf','alfa')
	spd = SelectPagesRotateDialog('fdaf',100)
	spd.run()
	print '%s'%int(spd.spin1.get_value())
	print '%s'%spd.rbutton1.get_active()
	#dialog_save_as('prueba','/home/atareao/log.log').run()
	#print create_temp_file()
	jpd = JoinPdfsDialog('orueba',['1','2','3','4','5','6'])
	if jpd.run() == Gtk.ResponseType.ACCEPT:
		files = jpd.get_pdf_files()
		print files
		jpd.destroy()
	'''
	#combine("/home/atareao/Escritorio/lorem.pdf","/home/atareao/Escritorio/document-output.pdf",filas=2,columnas=2,width=297,height=210,margen=0.0,byrows=True)
	'''
	file_in = "/home/atareao/Dropbox/issue54_en.pdf"
	file_out = "/home/atareao/Dropbox/Libro-Final-Facil-v4.txt"
	extract_text(file_in,file_out)
	'''
